| options.alt | R Documentation |
alt Objects
This function handles the various plotting options for alt objects.
options.alt(...)
... |
Options for plotting |
As a function, options.alt, borrows its internal structure from
the par function of package graphics.
Unlike its corresponding function in WeibullR options.wblr this function
is intended to only be called within plot.alt.
Executing options.alt without arguments returns a named list
containing the default options for plotting a alt object.
Should arguments be supplied, these are returned in a named list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.